//
//  ItemMovieView.swift
//  Jel
//
//  Created by zerocool on 12/23/23.
//

import SwiftUI
import JellyfinKit

struct ItemMovieView: View {
  @EnvironmentObject var jellyfinClient: JellyfinClientController
  @StateObject var authState: AuthStateController = AuthStateController.shared
  
  @State var item: BaseItemDto
  @State var loading: Bool = true
  
  var body: some View {
    ScrollView {
      ItemHeaderView(item: item)
      
      Text(item.taglines?[0] ?? "Unknown")
        .font(.headline)
        .padding(.top, 20)
      
      Text(item.overview ?? "Unknown")
        .padding()
    }
    .redacted(reason: loading ? .placeholder : [])
    .ignoresSafeArea(edges: .top)
    .toolbarRole(.editor)
    .navigationTitle(item.name ?? "Unknown")
    .navigationBarTitleDisplayMode(.inline)
    .onAppear {
      Task {
        do {
          let request = Paths.getItem(userID: authState.userId ?? "", itemID: item.id ?? "")
          item = try await jellyfinClient.send(request).value
          loading = false
        } catch {
        }
      }
    }
  }
}

#Preview {
  ItemMovieView(item: BaseItemDto())
}
